Class: Google::Apis::IamV1::AddAttestationRuleRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Request message for AddAttestationRule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AddAttestationRuleRequest

Returns a new instance of AddAttestationRuleRequest.



65
66
67
# File 'lib/google/apis/iam_v1/classes.rb', line 65

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attestation_ruleGoogle::Apis::IamV1::AttestationRule

Defines which workloads can receive an identity within a pool. When an AttestationRule is defined under a managed identity, matching workloads may receive that identity. Corresponds to the JSON property attestationRule



63
64
65
# File 'lib/google/apis/iam_v1/classes.rb', line 63

def attestation_rule
  @attestation_rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70
71
72
# File 'lib/google/apis/iam_v1/classes.rb', line 70

def update!(**args)
  @attestation_rule = args[:attestation_rule] if args.key?(:attestation_rule)
end