Class: Google::Apis::IamV1::ExtendedStatus
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::ExtendedStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Extended status can store additional metadata. For example, for keys disabled due to their private key data being expoesed we may include a message with more information about the exposure.
Instance Attribute Summary collapse
-
#key ⇒ String
The key for this extended status.
-
#value ⇒ String
The value for the extended status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtendedStatus
constructor
A new instance of ExtendedStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtendedStatus
Returns a new instance of ExtendedStatus.
646 647 648 |
# File 'lib/google/apis/iam_v1/classes.rb', line 646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
The key for this extended status.
Corresponds to the JSON property key
639 640 641 |
# File 'lib/google/apis/iam_v1/classes.rb', line 639 def key @key end |
#value ⇒ String
The value for the extended status.
Corresponds to the JSON property value
644 645 646 |
# File 'lib/google/apis/iam_v1/classes.rb', line 644 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
651 652 653 654 |
# File 'lib/google/apis/iam_v1/classes.rb', line 651 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |