Class: Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2ClientQueryParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents the parameters to control which claims are fetched from an IdP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2ClientQueryParameters

Returns a new instance of GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2ClientQueryParameters.



776
777
778
# File 'lib/google/apis/iam_v1/classes.rb', line 776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Optional. The filter used to request specific records from the IdP. By default, all of the groups that are associated with a user are fetched. For Microsoft Entra ID, you can add $search query parameters using Keyword Query Language. To learn more about $search querying in Microsoft Entra ID, see Use the $search query parameter. Additionally, Workforce Identity Federation automatically adds the following $filter query parameters, based on the value of attributes_type. Values passed to filter are converted to $search query parameters. Additional $filter query parameters cannot be added using this field. * AZURE_AD_GROUPS_MAIL: mailEnabled and securityEnabled filters are applied. * AZURE_AD_GROUPS_ID: securityEnabled filter is applied. Corresponds to the JSON property filter

Returns:

  • (String)


774
775
776
# File 'lib/google/apis/iam_v1/classes.rb', line 774

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



781
782
783
# File 'lib/google/apis/iam_v1/classes.rb', line 781

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
end