Class: Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Configuration for web single sign-on for the OIDC provider.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig

Returns a new instance of GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig.



892
893
894
# File 'lib/google/apis/iam_v1/classes.rb', line 892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_scopesArray<String>

Optional. Additional scopes to request for in the OIDC authentication request on top of scopes requested by default. By default, the openid, profile and email scopes that are supported by the identity provider are requested. Each additional scope may be at most 256 characters. A maximum of 10 additional scopes may be configured. Corresponds to the JSON property additionalScopes

Returns:

  • (Array<String>)


877
878
879
# File 'lib/google/apis/iam_v1/classes.rb', line 877

def additional_scopes
  @additional_scopes
end

#assertion_claims_behaviorString

Required. The behavior for how OIDC Claims are included in the assertion object used for attribute mapping and attribute condition. Corresponds to the JSON property assertionClaimsBehavior

Returns:

  • (String)


883
884
885
# File 'lib/google/apis/iam_v1/classes.rb', line 883

def assertion_claims_behavior
  @assertion_claims_behavior
end

#response_typeString

Required. The Response Type to request for in the OIDC Authorization Request for web sign-in. The CODE Response Type is recommended to avoid the Implicit Flow, for security reasons. Corresponds to the JSON property responseType

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/iam_v1/classes.rb', line 890

def response_type
  @response_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



897
898
899
900
901
# File 'lib/google/apis/iam_v1/classes.rb', line 897

def update!(**args)
  @additional_scopes = args[:additional_scopes] if args.key?(:additional_scopes)
  @assertion_claims_behavior = args[:assertion_claims_behavior] if args.key?(:assertion_claims_behavior)
  @response_type = args[:response_type] if args.key?(:response_type)
end