Class: Google::Apis::IamV1::InlineTrustConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Defines configuration for extending trust to additional trust domains. By establishing trust with another domain, the current domain will recognize and accept certificates issued by entities within the trusted domains. Note that a trust domain automatically trusts itself, eliminating the need for explicit configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InlineTrustConfig

Returns a new instance of InlineTrustConfig.



1034
1035
1036
# File 'lib/google/apis/iam_v1/classes.rb', line 1034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_trust_bundlesHash<String,Google::Apis::IamV1::TrustStore>

Optional. Maps specific trust domains (e.g., "example.com") to their corresponding TrustStore, which contain the trusted root certificates for that domain. There can be a maximum of 10 trust domain entries in this map. Note that a trust domain automatically trusts itself and don't need to be specified here. If however, this WorkloadIdentityPool's trust domain contains any trust anchors in the additional_trust_bundles map, those trust anchors will be * appended to* the trust bundle automatically derived from your InlineCertificateIssuanceConfig's ca_pools. Corresponds to the JSON property additionalTrustBundles

Returns:



1032
1033
1034
# File 'lib/google/apis/iam_v1/classes.rb', line 1032

def additional_trust_bundles
  @additional_trust_bundles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1039
1040
1041
# File 'lib/google/apis/iam_v1/classes.rb', line 1039

def update!(**args)
  @additional_trust_bundles = args[:additional_trust_bundles] if args.key?(:additional_trust_bundles)
end