Class: Google::Apis::IamV1::KeyData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a public key data along with its format.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyData

Returns a new instance of KeyData.



1098
1099
1100
# File 'lib/google/apis/iam_v1/classes.rb', line 1098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#formatString

Output only. The format of the key. Corresponds to the JSON property format

Returns:

  • (String)


1071
1072
1073
# File 'lib/google/apis/iam_v1/classes.rb', line 1071

def format
  @format
end

#keyString

Output only. The key data. The format of the key is represented by the format field. Corresponds to the JSON property key

Returns:

  • (String)


1077
1078
1079
# File 'lib/google/apis/iam_v1/classes.rb', line 1077

def key
  @key
end

#key_specString

Required. The specifications for the key. Corresponds to the JSON property keySpec

Returns:

  • (String)


1082
1083
1084
# File 'lib/google/apis/iam_v1/classes.rb', line 1082

def key_spec
  @key_spec
end

#not_after_timeString

Output only. Latest timestamp when this key is valid. Attempts to use this key after this time will fail. Only present if the key data represents a X.509 certificate. Corresponds to the JSON property notAfterTime

Returns:

  • (String)


1089
1090
1091
# File 'lib/google/apis/iam_v1/classes.rb', line 1089

def not_after_time
  @not_after_time
end

#not_before_timeString

Output only. Earliest timestamp when this key is valid. Attempts to use this key before this time will fail. Only present if the key data represents a X. 509 certificate. Corresponds to the JSON property notBeforeTime

Returns:

  • (String)


1096
1097
1098
# File 'lib/google/apis/iam_v1/classes.rb', line 1096

def not_before_time
  @not_before_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1103
1104
1105
1106
1107
1108
1109
# File 'lib/google/apis/iam_v1/classes.rb', line 1103

def update!(**args)
  @format = args[:format] if args.key?(:format)
  @key = args[:key] if args.key?(:key)
  @key_spec = args[:key_spec] if args.key?(:key_spec)
  @not_after_time = args[:not_after_time] if args.key?(:not_after_time)
  @not_before_time = args[:not_before_time] if args.key?(:not_before_time)
end