Class: Google::Apis::IamV1::LintPolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

The request to lint an IAM policy object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LintPolicyRequest

Returns a new instance of LintPolicyRequest.



1144
1145
1146
# File 'lib/google/apis/iam_v1/classes.rb', line 1144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionGoogle::Apis::IamV1::Expr

Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information. Corresponds to the JSON property condition



1133
1134
1135
# File 'lib/google/apis/iam_v1/classes.rb', line 1133

def condition
  @condition
end

#full_resource_nameString

The full resource name of the policy this lint request is about. The name follows the Google Cloud format for full resource names. For example, a Google Cloud project with ID my-project will be named //cloudresourcemanager. googleapis.com/projects/my-project. The resource name is not used to read a policy from IAM. Only the data in the request object is linted. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


1142
1143
1144
# File 'lib/google/apis/iam_v1/classes.rb', line 1142

def full_resource_name
  @full_resource_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1149
1150
1151
1152
# File 'lib/google/apis/iam_v1/classes.rb', line 1149

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
end