Class: Google::Apis::IamV1::OauthClient

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents an OauthClient. Used to access Google Cloud resources on behalf of a Workforce Identity Federation user by using OAuth 2.0 Protocol to obtain an access token from Google Cloud.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OauthClient

Returns a new instance of OauthClient.



1694
1695
1696
# File 'lib/google/apis/iam_v1/classes.rb', line 1694

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_grant_typesArray<String>

Required. The list of OAuth grant types is allowed for the OauthClient. Corresponds to the JSON property allowedGrantTypes

Returns:

  • (Array<String>)


1630
1631
1632
# File 'lib/google/apis/iam_v1/classes.rb', line 1630

def allowed_grant_types
  @allowed_grant_types
end

#allowed_redirect_urisArray<String>

Required. The list of redirect uris that is allowed to redirect back when authorization process is completed. Corresponds to the JSON property allowedRedirectUris

Returns:

  • (Array<String>)


1636
1637
1638
# File 'lib/google/apis/iam_v1/classes.rb', line 1636

def allowed_redirect_uris
  @allowed_redirect_uris
end

#allowed_scopesArray<String>

Required. The list of scopes that the OauthClient is allowed to request during OAuth flows. The following scopes are supported: * https://www.googleapis.com/ auth/cloud-platform: See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account. Corresponds to the JSON property allowedScopes

Returns:

  • (Array<String>)


1644
1645
1646
# File 'lib/google/apis/iam_v1/classes.rb', line 1644

def allowed_scopes
  @allowed_scopes
end

#client_idString

Output only. The system-generated OauthClient id. Corresponds to the JSON property clientId

Returns:

  • (String)


1649
1650
1651
# File 'lib/google/apis/iam_v1/classes.rb', line 1649

def client_id
  @client_id
end

#client_typeString

Immutable. The type of OauthClient. Either public or private. For private clients, the client secret can be managed using the dedicated OauthClientCredential resource. Corresponds to the JSON property clientType

Returns:

  • (String)


1656
1657
1658
# File 'lib/google/apis/iam_v1/classes.rb', line 1656

def client_type
  @client_type
end

#descriptionString

Optional. A user-specified description of the OauthClient. Cannot exceed 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


1662
1663
1664
# File 'lib/google/apis/iam_v1/classes.rb', line 1662

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Whether the OauthClient is disabled. You cannot use a disabled OAuth client. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


1668
1669
1670
# File 'lib/google/apis/iam_v1/classes.rb', line 1668

def disabled
  @disabled
end

#display_nameString

Optional. A user-specified display name of the OauthClient. Cannot exceed 32 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


1675
1676
1677
# File 'lib/google/apis/iam_v1/classes.rb', line 1675

def display_name
  @display_name
end

#expire_timeString

Output only. Time after which the OauthClient will be permanently purged and cannot be recovered. Corresponds to the JSON property expireTime

Returns:

  • (String)


1681
1682
1683
# File 'lib/google/apis/iam_v1/classes.rb', line 1681

def expire_time
  @expire_time
end

#nameString

Immutable. Identifier. The resource name of the OauthClient. Format:projects/ project/locations/location/oauthClients/oauth_client`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1687
1688
1689
# File 'lib/google/apis/iam_v1/classes.rb', line 1687

def name
  @name
end

#stateString

Output only. The state of the OauthClient. Corresponds to the JSON property state

Returns:

  • (String)


1692
1693
1694
# File 'lib/google/apis/iam_v1/classes.rb', line 1692

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
# File 'lib/google/apis/iam_v1/classes.rb', line 1699

def update!(**args)
  @allowed_grant_types = args[:allowed_grant_types] if args.key?(:allowed_grant_types)
  @allowed_redirect_uris = args[:allowed_redirect_uris] if args.key?(:allowed_redirect_uris)
  @allowed_scopes = args[:allowed_scopes] if args.key?(:allowed_scopes)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_type = args[:client_type] if args.key?(:client_type)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end