Class: Google::Apis::IamV1::PatchServiceAccountRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

The service account patch request. You can patch only the display_name and description fields. You must use the update_mask field to specify which of these fields you want to patch. Only the fields specified in the request are guaranteed to be returned in the response. Other fields may be empty in the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PatchServiceAccountRequest

Returns a new instance of PatchServiceAccountRequest.



1978
1979
1980
# File 'lib/google/apis/iam_v1/classes.rb', line 1978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountGoogle::Apis::IamV1::ServiceAccount

An IAM service account. A service account is an account for an application or a virtual machine (VM) instance, not a person. You can use a service account to call Google APIs. To learn more, read the overview of service accounts. When you create a service account, you specify the project ID that owns the service account, as well as a name that must be unique within the project. IAM uses these values to create an email address that identifies the service account. // Corresponds to the JSON property serviceAccount



1971
1972
1973
# File 'lib/google/apis/iam_v1/classes.rb', line 1971

def 
  @service_account
end

#update_maskString

Corresponds to the JSON property updateMask

Returns:

  • (String)


1976
1977
1978
# File 'lib/google/apis/iam_v1/classes.rb', line 1976

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1983
1984
1985
1986
# File 'lib/google/apis/iam_v1/classes.rb', line 1983

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end