Class: Google::Apis::IamV1::Permission

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

A permission which can be included by a role.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Permission

Returns a new instance of Permission.



2049
2050
2051
# File 'lib/google/apis/iam_v1/classes.rb', line 2049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_disabledBoolean Also known as: api_disabled?

The service API associated with the permission is not enabled. Corresponds to the JSON property apiDisabled

Returns:

  • (Boolean)


2009
2010
2011
# File 'lib/google/apis/iam_v1/classes.rb', line 2009

def api_disabled
  @api_disabled
end

#custom_roles_support_levelString

The current custom role support level. Corresponds to the JSON property customRolesSupportLevel

Returns:

  • (String)


2015
2016
2017
# File 'lib/google/apis/iam_v1/classes.rb', line 2015

def custom_roles_support_level
  @custom_roles_support_level
end

#descriptionString

A brief description of what this Permission is used for. Corresponds to the JSON property description

Returns:

  • (String)


2020
2021
2022
# File 'lib/google/apis/iam_v1/classes.rb', line 2020

def description
  @description
end

#nameString

The name of this Permission. Corresponds to the JSON property name

Returns:

  • (String)


2025
2026
2027
# File 'lib/google/apis/iam_v1/classes.rb', line 2025

def name
  @name
end

#only_in_predefined_rolesBoolean Also known as: only_in_predefined_roles?

Corresponds to the JSON property onlyInPredefinedRoles

Returns:

  • (Boolean)


2030
2031
2032
# File 'lib/google/apis/iam_v1/classes.rb', line 2030

def only_in_predefined_roles
  @only_in_predefined_roles
end

#primary_permissionString

The preferred name for this permission. If present, then this permission is an alias of, and equivalent to, the listed primary_permission. Corresponds to the JSON property primaryPermission

Returns:

  • (String)


2037
2038
2039
# File 'lib/google/apis/iam_v1/classes.rb', line 2037

def primary_permission
  @primary_permission
end

#stageString

The current launch stage of the permission. Corresponds to the JSON property stage

Returns:

  • (String)


2042
2043
2044
# File 'lib/google/apis/iam_v1/classes.rb', line 2042

def stage
  @stage
end

#titleString

The title of this Permission. Corresponds to the JSON property title

Returns:

  • (String)


2047
2048
2049
# File 'lib/google/apis/iam_v1/classes.rb', line 2047

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
# File 'lib/google/apis/iam_v1/classes.rb', line 2054

def update!(**args)
  @api_disabled = args[:api_disabled] if args.key?(:api_disabled)
  @custom_roles_support_level = args[:custom_roles_support_level] if args.key?(:custom_roles_support_level)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @only_in_predefined_roles = args[:only_in_predefined_roles] if args.key?(:only_in_predefined_roles)
  @primary_permission = args[:primary_permission] if args.key?(:primary_permission)
  @stage = args[:stage] if args.key?(:stage)
  @title = args[:title] if args.key?(:title)
end