Class: Google::Apis::IamV1::Saml

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents an SAML 2.0 identity provider.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Saml

Returns a new instance of Saml.



2496
2497
2498
# File 'lib/google/apis/iam_v1/classes.rb', line 2496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idp_metadata_xmlString

Required. SAML identity provider (IdP) configuration metadata XML doc. The XML document must comply with the SAML 2.0 specification. The maximum size of an acceptable XML document is 128K characters. The SAML metadata XML document must satisfy the following constraints: * Must contain an IdP Entity ID. * Must contain at least one non-expired signing certificate. * For each signing certificate, the expiration must be: * From no more than 7 days in the future.

  • To no more than 25 years in the future. * Up to three IdP signing keys are allowed. When updating the provider's metadata XML, at least one non-expired signing key must overlap with the existing metadata. This requirement is skipped if there are no non-expired signing keys present in the existing metadata. Corresponds to the JSON property idpMetadataXml

Returns:

  • (String)


2494
2495
2496
# File 'lib/google/apis/iam_v1/classes.rb', line 2494

def 
  @idp_metadata_xml
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2501
2502
2503
# File 'lib/google/apis/iam_v1/classes.rb', line 2501

def update!(**args)
  @idp_metadata_xml = args[:idp_metadata_xml] if args.key?(:idp_metadata_xml)
end