Class: Google::Apis::IamV1::TrustStore
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::TrustStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Trust store that contains trust anchors and optional intermediate CAs used in PKI to build a trust chain(trust hierarchy) and verify a client's identity.
Instance Attribute Summary collapse
-
#intermediate_cas ⇒ Array<Google::Apis::IamV1::IntermediateCa>
Optional.
-
#trust_anchors ⇒ Array<Google::Apis::IamV1::TrustAnchor>
Required.
-
#trust_default_shared_ca ⇒ Boolean
(also: #trust_default_shared_ca?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrustStore
constructor
A new instance of TrustStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrustStore
Returns a new instance of TrustStore.
3052 3053 3054 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#intermediate_cas ⇒ Array<Google::Apis::IamV1::IntermediateCa>
Optional. Set of intermediate CA certificates used for building the trust
chain to the trust anchor. Important: Intermediate CAs are only supported for
X.509 federation.
Corresponds to the JSON property intermediateCas
3034 3035 3036 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3034 def intermediate_cas @intermediate_cas end |
#trust_anchors ⇒ Array<Google::Apis::IamV1::TrustAnchor>
Required. List of trust anchors to be used while performing validation against
a given TrustStore. The incoming end entity's certificate must be in the trust
chain of one of the trust anchors here.
Corresponds to the JSON property trustAnchors
3041 3042 3043 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3041 def trust_anchors @trust_anchors end |
#trust_default_shared_ca ⇒ Boolean Also known as:
Optional. If set to True, the trust bundle will include the private ca managed
identity regional root public certificates. Important:
trust_default_shared_ca is only supported for managed identity trust domain
resource.
Corresponds to the JSON property trustDefaultSharedCa
3049 3050 3051 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3049 def trust_default_shared_ca @trust_default_shared_ca end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3057 3058 3059 3060 3061 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3057 def update!(**args) @intermediate_cas = args[:intermediate_cas] if args.key?(:intermediate_cas) @trust_anchors = args[:trust_anchors] if args.key?(:trust_anchors) @trust_default_shared_ca = args[:trust_default_shared_ca] if args.key?(:trust_default_shared_ca) end |