Class: Google::Apis::IamV1::WorkforcePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a collection of external workforces. Provides namespaces for federated users that can be referenced in IAM policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkforcePool

Returns a new instance of WorkforcePool.



3333
3334
3335
# File 'lib/google/apis/iam_v1/classes.rb', line 3333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_restrictionsGoogle::Apis::IamV1::AccessRestrictions

Access related restrictions on the workforce pool. Corresponds to the JSON property accessRestrictions



3280
3281
3282
# File 'lib/google/apis/iam_v1/classes.rb', line 3280

def access_restrictions
  @access_restrictions
end

#descriptionString

Optional. A description of the pool. Cannot exceed 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


3285
3286
3287
# File 'lib/google/apis/iam_v1/classes.rb', line 3285

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Disables the workforce pool. You cannot use a disabled pool to exchange tokens, or use existing tokens to access resources. If the pool is re- enabled, existing tokens grant access again. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3292
3293
3294
# File 'lib/google/apis/iam_v1/classes.rb', line 3292

def disabled
  @disabled
end

#display_nameString

Optional. A display name for the pool. Cannot exceed 32 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3298
3299
3300
# File 'lib/google/apis/iam_v1/classes.rb', line 3298

def display_name
  @display_name
end

#expire_timeString

Output only. Time after which the workforce pool will be permanently purged and cannot be recovered. Corresponds to the JSON property expireTime

Returns:

  • (String)


3304
3305
3306
# File 'lib/google/apis/iam_v1/classes.rb', line 3304

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the pool. Format: locations/location/ workforcePools/workforce_pool_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


3310
3311
3312
# File 'lib/google/apis/iam_v1/classes.rb', line 3310

def name
  @name
end

#parentString

Immutable. The resource name of the parent. Format: organizations/org-id`. Corresponds to the JSON propertyparent`

Returns:

  • (String)


3315
3316
3317
# File 'lib/google/apis/iam_v1/classes.rb', line 3315

def parent
  @parent
end

#session_durationString

Optional. Duration that the Google Cloud access tokens, console sign-in sessions, and gcloud sign-in sessions from this pool are valid. Must be greater than 15 minutes (900s) and less than 12 hours (43200s). If session_duration is not configured, minted credentials have a default duration of one hour (3600s). For SAML providers, the lifetime of the token is the minimum of the session_duration and the SessionNotOnOrAfter claim in the SAML assertion. Corresponds to the JSON property sessionDuration

Returns:

  • (String)


3326
3327
3328
# File 'lib/google/apis/iam_v1/classes.rb', line 3326

def session_duration
  @session_duration
end

#stateString

Output only. The state of the pool. Corresponds to the JSON property state

Returns:

  • (String)


3331
3332
3333
# File 'lib/google/apis/iam_v1/classes.rb', line 3331

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/google/apis/iam_v1/classes.rb', line 3338

def update!(**args)
  @access_restrictions = args[:access_restrictions] if args.key?(:access_restrictions)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @session_duration = args[:session_duration] if args.key?(:session_duration)
  @state = args[:state] if args.key?(:state)
end