Class: Google::Apis::IamV1::WorkforcePoolProviderKey
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::WorkforcePoolProviderKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents a public key configuration for a Workforce Pool Provider. The key can be configured in your identity provider to encrypt SAML assertions. Google holds the corresponding private key, which it uses to decrypt encrypted tokens.
Instance Attribute Summary collapse
-
#expire_time ⇒ String
Output only.
-
#key_data ⇒ Google::Apis::IamV1::KeyData
Represents a public key data along with its format.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#use ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkforcePoolProviderKey
constructor
A new instance of WorkforcePoolProviderKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkforcePoolProviderKey
Returns a new instance of WorkforcePoolProviderKey.
3555 3556 3557 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3555 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expire_time ⇒ String
Output only. The time after which the key will be permanently deleted and
cannot be recovered. Note that the key may get purged before this time if the
total limit of keys per provider is exceeded.
Corresponds to the JSON property expireTime
3532 3533 3534 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3532 def expire_time @expire_time end |
#key_data ⇒ Google::Apis::IamV1::KeyData
Represents a public key data along with its format.
Corresponds to the JSON property keyData
3537 3538 3539 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3537 def key_data @key_data end |
#name ⇒ String
Identifier. The resource name of the key. Format: locations/location/
workforcePools/workforce_pool_id/providers/provider_id/keys/key_id`
Corresponds to the JSON propertyname`
3543 3544 3545 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3543 def name @name end |
#state ⇒ String
Output only. The state of the key.
Corresponds to the JSON property state
3548 3549 3550 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3548 def state @state end |
#use ⇒ String
Required. The purpose of the key.
Corresponds to the JSON property use
3553 3554 3555 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3553 def use @use end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3560 3561 3562 3563 3564 3565 3566 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3560 def update!(**args) @expire_time = args[:expire_time] if args.key?(:expire_time) @key_data = args[:key_data] if args.key?(:key_data) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @use = args[:use] if args.key?(:use) end |