Class: Google::Apis::IamV1::WorkloadIdentityPoolManagedIdentity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a managed identity for a workload identity pool namespace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityPoolManagedIdentity

Returns a new instance of WorkloadIdentityPoolManagedIdentity.



3809
3810
3811
# File 'lib/google/apis/iam_v1/classes.rb', line 3809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. A description of the managed identity. Cannot exceed 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


3783
3784
3785
# File 'lib/google/apis/iam_v1/classes.rb', line 3783

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Whether the managed identity is disabled. If disabled, credentials may no longer be issued for the identity, however existing credentials will still be accepted until they expire. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3790
3791
3792
# File 'lib/google/apis/iam_v1/classes.rb', line 3790

def disabled
  @disabled
end

#expire_timeString

Output only. Time after which the managed identity will be permanently purged and cannot be recovered. Corresponds to the JSON property expireTime

Returns:

  • (String)


3797
3798
3799
# File 'lib/google/apis/iam_v1/classes.rb', line 3797

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the managed identity. Corresponds to the JSON property name

Returns:

  • (String)


3802
3803
3804
# File 'lib/google/apis/iam_v1/classes.rb', line 3802

def name
  @name
end

#stateString

Output only. The state of the managed identity. Corresponds to the JSON property state

Returns:

  • (String)


3807
3808
3809
# File 'lib/google/apis/iam_v1/classes.rb', line 3807

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3814
3815
3816
3817
3818
3819
3820
# File 'lib/google/apis/iam_v1/classes.rb', line 3814

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end