Class: Google::Apis::IamV1::WorkloadIdentityPoolNamespace

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a namespace for a workload identity pool. Namespaces are used to segment identities within the pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityPoolNamespace

Returns a new instance of WorkloadIdentityPoolNamespace.



3862
3863
3864
# File 'lib/google/apis/iam_v1/classes.rb', line 3862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. A description of the namespace. Cannot exceed 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


3831
3832
3833
# File 'lib/google/apis/iam_v1/classes.rb', line 3831

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Whether the namespace is disabled. If disabled, credentials may no longer be issued for identities within this namespace, however existing credentials will still be accepted until they expire. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3838
3839
3840
# File 'lib/google/apis/iam_v1/classes.rb', line 3838

def disabled
  @disabled
end

#expire_timeString

Output only. Time after which the namespace will be permanently purged and cannot be recovered. Corresponds to the JSON property expireTime

Returns:

  • (String)


3845
3846
3847
# File 'lib/google/apis/iam_v1/classes.rb', line 3845

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the namespace. Corresponds to the JSON property name

Returns:

  • (String)


3850
3851
3852
# File 'lib/google/apis/iam_v1/classes.rb', line 3850

def name
  @name
end

#owner_serviceGoogle::Apis::IamV1::OwnerService

The Google Cloud service that owns this namespace. Corresponds to the JSON property ownerService



3855
3856
3857
# File 'lib/google/apis/iam_v1/classes.rb', line 3855

def owner_service
  @owner_service
end

#stateString

Output only. The state of the namespace. Corresponds to the JSON property state

Returns:

  • (String)


3860
3861
3862
# File 'lib/google/apis/iam_v1/classes.rb', line 3860

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3867
3868
3869
3870
3871
3872
3873
3874
# File 'lib/google/apis/iam_v1/classes.rb', line 3867

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @owner_service = args[:owner_service] if args.key?(:owner_service)
  @state = args[:state] if args.key?(:state)
end