Class: Google::Apis::IamV1::X509

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

An X.509-type identity provider represents a CA. It is trusted to assert a client identity if the client has a certificate that chains up to this CA.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ X509

Returns a new instance of X509.



4092
4093
4094
# File 'lib/google/apis/iam_v1/classes.rb', line 4092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#trust_storeGoogle::Apis::IamV1::TrustStore

Trust store that contains trust anchors and optional intermediate CAs used in PKI to build a trust chain(trust hierarchy) and verify a client's identity. Corresponds to the JSON property trustStore



4090
4091
4092
# File 'lib/google/apis/iam_v1/classes.rb', line 4090

def trust_store
  @trust_store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4097
4098
4099
# File 'lib/google/apis/iam_v1/classes.rb', line 4097

def update!(**args)
  @trust_store = args[:trust_store] if args.key?(:trust_store)
end