Class: Google::Apis::IamV1::AttestationRule
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::AttestationRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Defines which workloads can receive an identity within a pool. When an AttestationRule is defined under a managed identity, matching workloads may receive that identity.
Instance Attribute Summary collapse
-
#google_cloud_resource ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttestationRule
constructor
A new instance of AttestationRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttestationRule
Returns a new instance of AttestationRule.
109 110 111 |
# File 'lib/google/apis/iam_v1/classes.rb', line 109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_cloud_resource ⇒ String
Optional. A single workload operating on Google Cloud. For example: //compute.
googleapis.com/projects/123/uid/zones/us-central1-a/instances/12345.
Corresponds to the JSON property googleCloudResource
107 108 109 |
# File 'lib/google/apis/iam_v1/classes.rb', line 107 def google_cloud_resource @google_cloud_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
114 115 116 |
# File 'lib/google/apis/iam_v1/classes.rb', line 114 def update!(**args) @google_cloud_resource = args[:google_cloud_resource] if args.key?(:google_cloud_resource) end |