Class: Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents the OAuth 2.0 client credential configuration for retrieving additional user attributes that are not present in the initial authentication credentials from the identity provider, for example, groups. See https:// datatracker.ietf.org/doc/html/rfc6749#section-4.4 for more details on client credentials grant flow.
Instance Attribute Summary collapse
-
#attributes_type ⇒ String
Required.
-
#client_id ⇒ String
Required.
-
#client_secret ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecret
Representation of a client secret configured for the OIDC provider.
-
#issuer_uri ⇒ String
Required.
-
#query_parameters ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2ClientQueryParameters
Represents the parameters to control which claims are fetched from an IdP.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
constructor
A new instance of GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
Returns a new instance of GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client.
724 725 726 |
# File 'lib/google/apis/iam_v1/classes.rb', line 724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes_type ⇒ String
Required. Represents the IdP and type of claims that should be fetched.
Corresponds to the JSON property attributesType
699 700 701 |
# File 'lib/google/apis/iam_v1/classes.rb', line 699 def attributes_type @attributes_type end |
#client_id ⇒ String
Required. The OAuth 2.0 client ID for retrieving extra attributes from the
identity provider. Required to get the Access Token using client credentials
grant flow.
Corresponds to the JSON property clientId
706 707 708 |
# File 'lib/google/apis/iam_v1/classes.rb', line 706 def client_id @client_id end |
#client_secret ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecret
Representation of a client secret configured for the OIDC provider.
Corresponds to the JSON property clientSecret
711 712 713 |
# File 'lib/google/apis/iam_v1/classes.rb', line 711 def client_secret @client_secret end |
#issuer_uri ⇒ String
Required. The OIDC identity provider's issuer URI. Must be a valid URI using
the https scheme. Required to get the OIDC discovery document.
Corresponds to the JSON property issuerUri
717 718 719 |
# File 'lib/google/apis/iam_v1/classes.rb', line 717 def issuer_uri @issuer_uri end |
#query_parameters ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2ClientQueryParameters
Represents the parameters to control which claims are fetched from an IdP.
Corresponds to the JSON property queryParameters
722 723 724 |
# File 'lib/google/apis/iam_v1/classes.rb', line 722 def query_parameters @query_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
729 730 731 732 733 734 735 |
# File 'lib/google/apis/iam_v1/classes.rb', line 729 def update!(**args) @attributes_type = args[:attributes_type] if args.key?(:attributes_type) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @issuer_uri = args[:issuer_uri] if args.key?(:issuer_uri) @query_parameters = args[:query_parameters] if args.key?(:query_parameters) end |