Class: Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents the OAuth 2.0 client credential configuration for retrieving additional user attributes that are not present in the initial authentication credentials from the identity provider, for example, groups. See https:// datatracker.ietf.org/doc/html/rfc6749#section-4.4 for more details on client credentials grant flow.
Instance Attribute Summary collapse
-
#attributes_type ⇒ String
Required.
-
#client_id ⇒ String
Required.
-
#client_secret ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecret
Representation of a client secret configured for the OIDC provider.
-
#issuer_uri ⇒ String
Required.
-
#query_parameters ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2ClientQueryParameters
Represents the parameters to control which claims are fetched from an IdP.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
constructor
A new instance of GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
Returns a new instance of GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client.
740 741 742 |
# File 'lib/google/apis/iam_v1/classes.rb', line 740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes_type ⇒ String
Required. Represents the IdP and type of claims that should be fetched.
Corresponds to the JSON property attributesType
715 716 717 |
# File 'lib/google/apis/iam_v1/classes.rb', line 715 def attributes_type @attributes_type end |
#client_id ⇒ String
Required. The OAuth 2.0 client ID for retrieving extra attributes from the
identity provider. Required to get the Access Token using client credentials
grant flow.
Corresponds to the JSON property clientId
722 723 724 |
# File 'lib/google/apis/iam_v1/classes.rb', line 722 def client_id @client_id end |
#client_secret ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecret
Representation of a client secret configured for the OIDC provider.
Corresponds to the JSON property clientSecret
727 728 729 |
# File 'lib/google/apis/iam_v1/classes.rb', line 727 def client_secret @client_secret end |
#issuer_uri ⇒ String
Required. The OIDC identity provider's issuer URI. Must be a valid URI using
the https scheme. Required to get the OIDC discovery document.
Corresponds to the JSON property issuerUri
733 734 735 |
# File 'lib/google/apis/iam_v1/classes.rb', line 733 def issuer_uri @issuer_uri end |
#query_parameters ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2ClientQueryParameters
Represents the parameters to control which claims are fetched from an IdP.
Corresponds to the JSON property queryParameters
738 739 740 |
# File 'lib/google/apis/iam_v1/classes.rb', line 738 def query_parameters @query_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
745 746 747 748 749 750 751 |
# File 'lib/google/apis/iam_v1/classes.rb', line 745 def update!(**args) @attributes_type = args[:attributes_type] if args.key?(:attributes_type) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @issuer_uri = args[:issuer_uri] if args.key?(:issuer_uri) @query_parameters = args[:query_parameters] if args.key?(:query_parameters) end |