Class: Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidc
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidc
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents an OpenID Connect 1.0 identity provider.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Required.
-
#client_secret ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecret
Representation of a client secret configured for the OIDC provider.
-
#issuer_uri ⇒ String
Required.
-
#jwks_json ⇒ String
Optional.
-
#web_sso_config ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig
Configuration for web single sign-on for the OIDC provider.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderOidc
constructor
A new instance of GoogleIamAdminV1WorkforcePoolProviderOidc.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderOidc
Returns a new instance of GoogleIamAdminV1WorkforcePoolProviderOidc.
822 823 824 |
# File 'lib/google/apis/iam_v1/classes.rb', line 822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Required. The client ID. Must match the audience claim of the JWT issued by
the identity provider.
Corresponds to the JSON property clientId
794 795 796 |
# File 'lib/google/apis/iam_v1/classes.rb', line 794 def client_id @client_id end |
#client_secret ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecret
Representation of a client secret configured for the OIDC provider.
Corresponds to the JSON property clientSecret
799 800 801 |
# File 'lib/google/apis/iam_v1/classes.rb', line 799 def client_secret @client_secret end |
#issuer_uri ⇒ String
Required. The OIDC issuer URI. Must be a valid URI using the https scheme.
Corresponds to the JSON property issuerUri
804 805 806 |
# File 'lib/google/apis/iam_v1/classes.rb', line 804 def issuer_uri @issuer_uri end |
#jwks_json ⇒ String
Optional. OIDC JWKs in JSON String format. For details on the definition of a
JWK, see https://tools.ietf.org/html/rfc7517. If not set, the jwks_uri from
the discovery document that is fetched from the well-known path of the
issuer_uri, will be used. RSA and EC asymmetric keys are supported. The JWK
must use the following format and include only the following fields: "keys":
[ "kty": "RSA/EC", "alg": "", "use": "sig", "kid": "", "n": "", "e": "", "x":
"", "y": "", "crv": "" ]
Corresponds to the JSON property jwksJson
815 816 817 |
# File 'lib/google/apis/iam_v1/classes.rb', line 815 def jwks_json @jwks_json end |
#web_sso_config ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig
Configuration for web single sign-on for the OIDC provider.
Corresponds to the JSON property webSsoConfig
820 821 822 |
# File 'lib/google/apis/iam_v1/classes.rb', line 820 def web_sso_config @web_sso_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
827 828 829 830 831 832 833 |
# File 'lib/google/apis/iam_v1/classes.rb', line 827 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @issuer_uri = args[:issuer_uri] if args.key?(:issuer_uri) @jwks_json = args[:jwks_json] if args.key?(:jwks_json) @web_sso_config = args[:web_sso_config] if args.key?(:web_sso_config) end |