Class: Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecretValue
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcClientSecretValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Representation of the value of the client secret.
Instance Attribute Summary collapse
-
#plain_text ⇒ String
Optional.
-
#thumbprint ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderOidcClientSecretValue
constructor
A new instance of GoogleIamAdminV1WorkforcePoolProviderOidcClientSecretValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderOidcClientSecretValue
Returns a new instance of GoogleIamAdminV1WorkforcePoolProviderOidcClientSecretValue.
871 872 873 |
# File 'lib/google/apis/iam_v1/classes.rb', line 871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#plain_text ⇒ String
Optional. Input only. The plain text of the client secret value. For security
reasons, this field is only used for input and will never be populated in any
response.
Corresponds to the JSON property plainText
864 865 866 |
# File 'lib/google/apis/iam_v1/classes.rb', line 864 def plain_text @plain_text end |
#thumbprint ⇒ String
Output only. A thumbprint to represent the current client secret value.
Corresponds to the JSON property thumbprint
869 870 871 |
# File 'lib/google/apis/iam_v1/classes.rb', line 869 def thumbprint @thumbprint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
876 877 878 879 |
# File 'lib/google/apis/iam_v1/classes.rb', line 876 def update!(**args) @plain_text = args[:plain_text] if args.key?(:plain_text) @thumbprint = args[:thumbprint] if args.key?(:thumbprint) end |