Class: Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Configuration for web single sign-on for the OIDC provider.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig

Returns a new instance of GoogleIamAdminV1WorkforcePoolProviderOidcWebSsoConfig.



908
909
910
# File 'lib/google/apis/iam_v1/classes.rb', line 908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_scopesArray<String>

Optional. Additional scopes to request for in the OIDC authentication request on top of scopes requested by default. By default, the openid, profile and email scopes that are supported by the identity provider are requested. Each additional scope may be at most 256 characters. A maximum of 10 additional scopes may be configured. Corresponds to the JSON property additionalScopes

Returns:

  • (Array<String>)


893
894
895
# File 'lib/google/apis/iam_v1/classes.rb', line 893

def additional_scopes
  @additional_scopes
end

#assertion_claims_behaviorString

Required. The behavior for how OIDC Claims are included in the assertion object used for attribute mapping and attribute condition. Corresponds to the JSON property assertionClaimsBehavior

Returns:

  • (String)


899
900
901
# File 'lib/google/apis/iam_v1/classes.rb', line 899

def assertion_claims_behavior
  @assertion_claims_behavior
end

#response_typeString

Required. The Response Type to request for in the OIDC Authorization Request for web sign-in. The CODE Response Type is recommended to avoid the Implicit Flow, for security reasons. Corresponds to the JSON property responseType

Returns:

  • (String)


906
907
908
# File 'lib/google/apis/iam_v1/classes.rb', line 906

def response_type
  @response_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



913
914
915
916
917
# File 'lib/google/apis/iam_v1/classes.rb', line 913

def update!(**args)
  @additional_scopes = args[:additional_scopes] if args.key?(:additional_scopes)
  @assertion_claims_behavior = args[:assertion_claims_behavior] if args.key?(:assertion_claims_behavior)
  @response_type = args[:response_type] if args.key?(:response_type)
end