Class: Google::Apis::IamV1::OauthClient
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::OauthClient
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents an OauthClient. Used to access Google Cloud resources on behalf of a Workforce Identity Federation user by using OAuth 2.0 Protocol to obtain an access token from Google Cloud.
Instance Attribute Summary collapse
-
#allowed_grant_types ⇒ Array<String>
Required.
-
#allowed_redirect_uris ⇒ Array<String>
Required.
-
#allowed_scopes ⇒ Array<String>
Required.
-
#client_id ⇒ String
Output only.
-
#client_type ⇒ String
Immutable.
-
#description ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OauthClient
constructor
A new instance of OauthClient.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OauthClient
Returns a new instance of OauthClient.
1697 1698 1699 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_grant_types ⇒ Array<String>
Required. The list of OAuth grant types is allowed for the OauthClient.
Corresponds to the JSON property allowedGrantTypes
1633 1634 1635 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1633 def allowed_grant_types @allowed_grant_types end |
#allowed_redirect_uris ⇒ Array<String>
Required. The list of redirect uris that is allowed to redirect back when
authorization process is completed.
Corresponds to the JSON property allowedRedirectUris
1639 1640 1641 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1639 def allowed_redirect_uris @allowed_redirect_uris end |
#allowed_scopes ⇒ Array<String>
Required. The list of scopes that the OauthClient is allowed to request during
OAuth flows. The following scopes are supported: * https://www.googleapis.com/
auth/cloud-platform: See, edit, configure, and delete your Google Cloud data
and see the email address for your Google Account.
Corresponds to the JSON property allowedScopes
1647 1648 1649 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1647 def allowed_scopes @allowed_scopes end |
#client_id ⇒ String
Output only. The system-generated OauthClient id.
Corresponds to the JSON property clientId
1652 1653 1654 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1652 def client_id @client_id end |
#client_type ⇒ String
Immutable. The type of OauthClient. Either public or private. For private
clients, the client secret can be managed using the dedicated
OauthClientCredential resource.
Corresponds to the JSON property clientType
1659 1660 1661 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1659 def client_type @client_type end |
#description ⇒ String
Optional. A user-specified description of the OauthClient. Cannot exceed 256
characters.
Corresponds to the JSON property description
1665 1666 1667 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1665 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Whether the OauthClient is disabled. You cannot use a disabled OAuth
client.
Corresponds to the JSON property disabled
1671 1672 1673 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1671 def disabled @disabled end |
#display_name ⇒ String
Optional. A user-specified display name of the OauthClient. Cannot exceed 32
characters.
Corresponds to the JSON property displayName
1678 1679 1680 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1678 def display_name @display_name end |
#expire_time ⇒ String
Output only. Time after which the OauthClient will be permanently purged and
cannot be recovered.
Corresponds to the JSON property expireTime
1684 1685 1686 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1684 def expire_time @expire_time end |
#name ⇒ String
Immutable. Identifier. The resource name of the OauthClient. Format:projects/
project/locations/location/oauthClients/oauth_client`.
Corresponds to the JSON propertyname`
1690 1691 1692 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1690 def name @name end |
#state ⇒ String
Output only. The state of the OauthClient.
Corresponds to the JSON property state
1695 1696 1697 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1695 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/google/apis/iam_v1/classes.rb', line 1702 def update!(**args) @allowed_grant_types = args[:allowed_grant_types] if args.key?(:allowed_grant_types) @allowed_redirect_uris = args[:allowed_redirect_uris] if args.key?(:allowed_redirect_uris) @allowed_scopes = args[:allowed_scopes] if args.key?(:allowed_scopes) @client_id = args[:client_id] if args.key?(:client_id) @client_type = args[:client_type] if args.key?(:client_type) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |