Class: Google::Apis::IamV1::Permission
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::Permission
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
A permission which can be included by a role.
Instance Attribute Summary collapse
-
#api_disabled ⇒ Boolean
(also: #api_disabled?)
The service API associated with the permission is not enabled.
-
#custom_roles_support_level ⇒ String
The current custom role support level.
-
#description ⇒ String
A brief description of what this Permission is used for.
-
#name ⇒ String
The name of this Permission.
-
#only_in_predefined_roles ⇒ Boolean
(also: #only_in_predefined_roles?)
Corresponds to the JSON property
onlyInPredefinedRoles. -
#primary_permission ⇒ String
The preferred name for this permission.
-
#stage ⇒ String
The current launch stage of the permission.
-
#title ⇒ String
The title of this Permission.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Permission
constructor
A new instance of Permission.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Permission
Returns a new instance of Permission.
2049 2050 2051 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_disabled ⇒ Boolean Also known as: api_disabled?
The service API associated with the permission is not enabled.
Corresponds to the JSON property apiDisabled
2009 2010 2011 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2009 def api_disabled @api_disabled end |
#custom_roles_support_level ⇒ String
The current custom role support level.
Corresponds to the JSON property customRolesSupportLevel
2015 2016 2017 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2015 def custom_roles_support_level @custom_roles_support_level end |
#description ⇒ String
A brief description of what this Permission is used for.
Corresponds to the JSON property description
2020 2021 2022 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2020 def description @description end |
#name ⇒ String
The name of this Permission.
Corresponds to the JSON property name
2025 2026 2027 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2025 def name @name end |
#only_in_predefined_roles ⇒ Boolean Also known as: only_in_predefined_roles?
Corresponds to the JSON property onlyInPredefinedRoles
2030 2031 2032 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2030 def only_in_predefined_roles @only_in_predefined_roles end |
#primary_permission ⇒ String
The preferred name for this permission. If present, then this permission is an
alias of, and equivalent to, the listed primary_permission.
Corresponds to the JSON property primaryPermission
2037 2038 2039 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2037 def @primary_permission end |
#stage ⇒ String
The current launch stage of the permission.
Corresponds to the JSON property stage
2042 2043 2044 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2042 def stage @stage end |
#title ⇒ String
The title of this Permission.
Corresponds to the JSON property title
2047 2048 2049 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2047 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2054 def update!(**args) @api_disabled = args[:api_disabled] if args.key?(:api_disabled) @custom_roles_support_level = args[:custom_roles_support_level] if args.key?(:custom_roles_support_level) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @only_in_predefined_roles = args[:only_in_predefined_roles] if args.key?(:only_in_predefined_roles) @primary_permission = args[:primary_permission] if args.key?(:primary_permission) @stage = args[:stage] if args.key?(:stage) @title = args[:title] if args.key?(:title) end |