Class: Google::Apis::IamV1::Permission

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

A permission which can be included by a role.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Permission

Returns a new instance of Permission.



2036
2037
2038
# File 'lib/google/apis/iam_v1/classes.rb', line 2036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_disabledBoolean Also known as: api_disabled?

The service API associated with the permission is not enabled. Corresponds to the JSON property apiDisabled

Returns:

  • (Boolean)


1996
1997
1998
# File 'lib/google/apis/iam_v1/classes.rb', line 1996

def api_disabled
  @api_disabled
end

#custom_roles_support_levelString

The current custom role support level. Corresponds to the JSON property customRolesSupportLevel

Returns:

  • (String)


2002
2003
2004
# File 'lib/google/apis/iam_v1/classes.rb', line 2002

def custom_roles_support_level
  @custom_roles_support_level
end

#descriptionString

A brief description of what this Permission is used for. Corresponds to the JSON property description

Returns:

  • (String)


2007
2008
2009
# File 'lib/google/apis/iam_v1/classes.rb', line 2007

def description
  @description
end

#nameString

The name of this Permission. Corresponds to the JSON property name

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/iam_v1/classes.rb', line 2012

def name
  @name
end

#only_in_predefined_rolesBoolean Also known as: only_in_predefined_roles?

Corresponds to the JSON property onlyInPredefinedRoles

Returns:

  • (Boolean)


2017
2018
2019
# File 'lib/google/apis/iam_v1/classes.rb', line 2017

def only_in_predefined_roles
  @only_in_predefined_roles
end

#primary_permissionString

The preferred name for this permission. If present, then this permission is an alias of, and equivalent to, the listed primary_permission. Corresponds to the JSON property primaryPermission

Returns:

  • (String)


2024
2025
2026
# File 'lib/google/apis/iam_v1/classes.rb', line 2024

def primary_permission
  @primary_permission
end

#stageString

The current launch stage of the permission. Corresponds to the JSON property stage

Returns:

  • (String)


2029
2030
2031
# File 'lib/google/apis/iam_v1/classes.rb', line 2029

def stage
  @stage
end

#titleString

The title of this Permission. Corresponds to the JSON property title

Returns:

  • (String)


2034
2035
2036
# File 'lib/google/apis/iam_v1/classes.rb', line 2034

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
# File 'lib/google/apis/iam_v1/classes.rb', line 2041

def update!(**args)
  @api_disabled = args[:api_disabled] if args.key?(:api_disabled)
  @custom_roles_support_level = args[:custom_roles_support_level] if args.key?(:custom_roles_support_level)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @only_in_predefined_roles = args[:only_in_predefined_roles] if args.key?(:only_in_predefined_roles)
  @primary_permission = args[:primary_permission] if args.key?(:primary_permission)
  @stage = args[:stage] if args.key?(:stage)
  @title = args[:title] if args.key?(:title)
end