Class: Google::Apis::IamV1::QueryGrantableRolesRequest
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::QueryGrantableRolesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
The grantable role query request.
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
Required.
-
#page_size ⇒ Fixnum
Optional limit on the number of roles to include in the response.
-
#page_token ⇒ String
Optional pagination token returned in an earlier QueryGrantableRolesResponse.
-
#view ⇒ String
Corresponds to the JSON property
view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryGrantableRolesRequest
constructor
A new instance of QueryGrantableRolesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryGrantableRolesRequest
Returns a new instance of QueryGrantableRolesRequest.
2262 2263 2264 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2262 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
Required. Required. The full resource name to query from the list of grantable
roles. The name follows the Google Cloud Platform resource format. For example,
a Cloud Platform project with id my-project will be named //
cloudresourcemanager.googleapis.com/projects/my-project.
Corresponds to the JSON property fullResourceName
2244 2245 2246 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2244 def full_resource_name @full_resource_name end |
#page_size ⇒ Fixnum
Optional limit on the number of roles to include in the response. The default
is 300, and the maximum is 2,000.
Corresponds to the JSON property pageSize
2250 2251 2252 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2250 def page_size @page_size end |
#page_token ⇒ String
Optional pagination token returned in an earlier QueryGrantableRolesResponse.
Corresponds to the JSON property pageToken
2255 2256 2257 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2255 def page_token @page_token end |
#view ⇒ String
Corresponds to the JSON property view
2260 2261 2262 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2260 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2267 2268 2269 2270 2271 2272 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2267 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @view = args[:view] if args.key?(:view) end |