Class: Google::Apis::IamV1::QueryTestablePermissionsRequest
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::QueryTestablePermissionsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
A request to get permissions which can be tested on a resource.
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
Required.
-
#page_size ⇒ Fixnum
Optional limit on the number of permissions to include in the response.
-
#page_token ⇒ String
Optional pagination token returned in an earlier QueryTestablePermissionsRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryTestablePermissionsRequest
constructor
A new instance of QueryTestablePermissionsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryTestablePermissionsRequest
Returns a new instance of QueryTestablePermissionsRequest.
2338 2339 2340 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
Required. The full resource name to query from the list of testable
permissions. The name follows the Google Cloud Platform resource format. For
example, a Cloud Platform project with id my-project will be named //
cloudresourcemanager.googleapis.com/projects/my-project.
Corresponds to the JSON property fullResourceName
2324 2325 2326 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2324 def full_resource_name @full_resource_name end |
#page_size ⇒ Fixnum
Optional limit on the number of permissions to include in the response. The
default is 100, and the maximum is 1,000.
Corresponds to the JSON property pageSize
2330 2331 2332 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2330 def page_size @page_size end |
#page_token ⇒ String
Optional pagination token returned in an earlier
QueryTestablePermissionsRequest.
Corresponds to the JSON property pageToken
2336 2337 2338 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2336 def page_token @page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2343 2344 2345 2346 2347 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2343 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) end |