Class: Google::Apis::IamV1::QueryTestablePermissionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

A request to get permissions which can be tested on a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryTestablePermissionsRequest

Returns a new instance of QueryTestablePermissionsRequest.



2325
2326
2327
# File 'lib/google/apis/iam_v1/classes.rb', line 2325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_resource_nameString

Required. The full resource name to query from the list of testable permissions. The name follows the Google Cloud Platform resource format. For example, a Cloud Platform project with id my-project will be named // cloudresourcemanager.googleapis.com/projects/my-project. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


2311
2312
2313
# File 'lib/google/apis/iam_v1/classes.rb', line 2311

def full_resource_name
  @full_resource_name
end

#page_sizeFixnum

Optional limit on the number of permissions to include in the response. The default is 100, and the maximum is 1,000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


2317
2318
2319
# File 'lib/google/apis/iam_v1/classes.rb', line 2317

def page_size
  @page_size
end

#page_tokenString

Optional pagination token returned in an earlier QueryTestablePermissionsRequest. Corresponds to the JSON property pageToken

Returns:

  • (String)


2323
2324
2325
# File 'lib/google/apis/iam_v1/classes.rb', line 2323

def page_token
  @page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2330
2331
2332
2333
2334
# File 'lib/google/apis/iam_v1/classes.rb', line 2330

def update!(**args)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
end