Class: Google::Apis::IamV1::RemoveAttestationRuleRequest
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::RemoveAttestationRuleRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Request message for RemoveAttestationRule.
Instance Attribute Summary collapse
-
#attestation_rule ⇒ Google::Apis::IamV1::AttestationRule
Defines which workloads can receive an identity within a pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAttestationRuleRequest
constructor
A new instance of RemoveAttestationRuleRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAttestationRuleRequest
Returns a new instance of RemoveAttestationRuleRequest.
2400 2401 2402 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attestation_rule ⇒ Google::Apis::IamV1::AttestationRule
Defines which workloads can receive an identity within a pool. When an
AttestationRule is defined under a managed identity, matching workloads may
receive that identity.
Corresponds to the JSON property attestationRule
2398 2399 2400 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2398 def attestation_rule @attestation_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2405 2406 2407 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2405 def update!(**args) @attestation_rule = args[:attestation_rule] if args.key?(:attestation_rule) end |