Class: Google::Apis::IamV1::Role
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::Role
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
A role in the Identity and Access Management API.
Instance Attribute Summary collapse
-
#deleted ⇒ Boolean
(also: #deleted?)
The current deleted state of the role.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Used to perform a consistent read-modify-write.
-
#included_permissions ⇒ Array<String>
The names of the permissions this role grants when bound in an IAM policy.
-
#name ⇒ String
The name of the role.
-
#stage ⇒ String
The current launch stage of the role.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Role
constructor
A new instance of Role.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Role
Returns a new instance of Role.
2457 2458 2459 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ Boolean Also known as: deleted?
The current deleted state of the role. This field is read only. It will be
ignored in calls to CreateRole and UpdateRole.
Corresponds to the JSON property deleted
2415 2416 2417 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2415 def deleted @deleted end |
#description ⇒ String
Optional. A human-readable description for the role.
Corresponds to the JSON property description
2421 2422 2423 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2421 def description @description end |
#etag ⇒ String
Used to perform a consistent read-modify-write.
Corresponds to the JSON property etag
NOTE: Values are automatically base64 encoded/decoded in the client library.
2427 2428 2429 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2427 def etag @etag end |
#included_permissions ⇒ Array<String>
The names of the permissions this role grants when bound in an IAM policy.
Corresponds to the JSON property includedPermissions
2432 2433 2434 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2432 def @included_permissions end |
#name ⇒ String
The name of the role. When Role is used in CreateRole, the role name must
not be set. When Role is used in output and other input such as UpdateRole,
the role name is the complete path. For example, roles/logging.viewer for
predefined roles, organizations/ORGANIZATION_ID/roles/myRole for
organization-level custom roles, and projects/PROJECT_ID/roles/myRole for
project-level custom roles.
Corresponds to the JSON property name
2442 2443 2444 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2442 def name @name end |
#stage ⇒ String
The current launch stage of the role. If the ALPHA launch stage has been
selected for a role, the stage field will not be included in the returned
definition for the role.
Corresponds to the JSON property stage
2449 2450 2451 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2449 def stage @stage end |
#title ⇒ String
Optional. A human-readable title for the role. Typically this is limited to
100 UTF-8 bytes.
Corresponds to the JSON property title
2455 2456 2457 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2455 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2462 2463 2464 2465 2466 2467 2468 2469 2470 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2462 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @included_permissions = args[:included_permissions] if args.key?(:included_permissions) @name = args[:name] if args.key?(:name) @stage = args[:stage] if args.key?(:stage) @title = args[:title] if args.key?(:title) end |