Class: Google::Apis::IamV1::ServiceAccountKey
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::ServiceAccountKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents a service account key. A service account has two sets of key-pairs: user-managed and system-managed. System-managed keys are also called Google- owned and managed keys. User-managed key-pairs can be created and deleted by users. Users are responsible for rotating these keys periodically to ensure security of their service accounts. Users retain the private key of these key- pairs, and Google retains ONLY the public key. System-managed keys that are actively used for signing are rotated regularly according to security best practices. The rotation process is probabilistic, and usage of the new key will gradually ramp up and down over the key's lifetime. If you cache the public key set for a service account, we recommend that you update the cache every 15 minutes. User-managed keys can be added and removed at any time, so it is important to update the cache frequently. For Google-managed keys, Google will publish a key at least 6 hours before it is first used for signing and will keep publishing it for at least 6 hours after it was last used for signing. Public keys for all service accounts are also published at the OAuth2 Service Account API.
Instance Attribute Summary collapse
-
#disable_reason ⇒ String
Output only.
-
#disabled ⇒ Boolean
(also: #disabled?)
The key status.
-
#extended_status ⇒ Array<Google::Apis::IamV1::ExtendedStatus>
Output only.
-
#key_algorithm ⇒ String
Specifies the algorithm (and possibly key size) for the key.
-
#key_origin ⇒ String
The key origin.
-
#key_type ⇒ String
The key type.
-
#name ⇒ String
The resource name of the service account key in the following format
projects/PROJECT_ID/serviceAccounts/ACCOUNT/keys/key``. -
#private_key_data ⇒ String
The private key data.
-
#private_key_type ⇒ String
The output format for the private key.
-
#public_key_data ⇒ String
The public key data.
-
#valid_after_time ⇒ String
The key can be used after this timestamp.
-
#valid_before_time ⇒ String
The key can be used before this timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAccountKey
constructor
A new instance of ServiceAccountKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAccountKey
Returns a new instance of ServiceAccountKey.
2690 2691 2692 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_reason ⇒ String
Output only. optional. If the key is disabled, it may have a DisableReason
describing why it was disabled.
Corresponds to the JSON property disableReason
2617 2618 2619 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2617 def disable_reason @disable_reason end |
#disabled ⇒ Boolean Also known as: disabled?
The key status.
Corresponds to the JSON property disabled
2622 2623 2624 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2622 def disabled @disabled end |
#extended_status ⇒ Array<Google::Apis::IamV1::ExtendedStatus>
Output only. Extended Status provides permanent information about a service
account key. For example, if this key was detected as exposed or compromised,
that information will remain for the lifetime of the key in the
extended_status.
Corresponds to the JSON property extendedStatus
2631 2632 2633 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2631 def extended_status @extended_status end |
#key_algorithm ⇒ String
Specifies the algorithm (and possibly key size) for the key.
Corresponds to the JSON property keyAlgorithm
2636 2637 2638 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2636 def key_algorithm @key_algorithm end |
#key_origin ⇒ String
The key origin.
Corresponds to the JSON property keyOrigin
2641 2642 2643 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2641 def key_origin @key_origin end |
#key_type ⇒ String
The key type.
Corresponds to the JSON property keyType
2646 2647 2648 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2646 def key_type @key_type end |
#name ⇒ String
The resource name of the service account key in the following format projects/
PROJECT_ID/serviceAccounts/ACCOUNT/keys/key`.
Corresponds to the JSON propertyname`
2652 2653 2654 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2652 def name @name end |
#private_key_data ⇒ String
The private key data. Only provided in CreateServiceAccountKey responses.
Make sure to keep the private key data secure because it allows for the
assertion of the service account identity. When base64 decoded, the private
key data can be used to authenticate with Google API client libraries and with
gcloud auth activate-service-account.
Corresponds to the JSON property privateKeyData
NOTE: Values are automatically base64 encoded/decoded in the client library.
2662 2663 2664 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2662 def private_key_data @private_key_data end |
#private_key_type ⇒ String
The output format for the private key. Only provided in
CreateServiceAccountKey responses, not in GetServiceAccountKey or
ListServiceAccountKey responses. Google never exposes system-managed private
keys, and never retains user-managed private keys.
Corresponds to the JSON property privateKeyType
2670 2671 2672 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2670 def private_key_type @private_key_type end |
#public_key_data ⇒ String
The public key data. Only provided in GetServiceAccountKey responses.
Corresponds to the JSON property publicKeyData
NOTE: Values are automatically base64 encoded/decoded in the client library.
2676 2677 2678 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2676 def public_key_data @public_key_data end |
#valid_after_time ⇒ String
The key can be used after this timestamp.
Corresponds to the JSON property validAfterTime
2681 2682 2683 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2681 def valid_after_time @valid_after_time end |
#valid_before_time ⇒ String
The key can be used before this timestamp. For system-managed key pairs, this
timestamp is the end time for the private key signing operation. The public
key could still be used for verification for a few hours after this time.
Corresponds to the JSON property validBeforeTime
2688 2689 2690 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2688 def valid_before_time @valid_before_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 |
# File 'lib/google/apis/iam_v1/classes.rb', line 2695 def update!(**args) @disable_reason = args[:disable_reason] if args.key?(:disable_reason) @disabled = args[:disabled] if args.key?(:disabled) @extended_status = args[:extended_status] if args.key?(:extended_status) @key_algorithm = args[:key_algorithm] if args.key?(:key_algorithm) @key_origin = args[:key_origin] if args.key?(:key_origin) @key_type = args[:key_type] if args.key?(:key_type) @name = args[:name] if args.key?(:name) @private_key_data = args[:private_key_data] if args.key?(:private_key_data) @private_key_type = args[:private_key_type] if args.key?(:private_key_type) @public_key_data = args[:public_key_data] if args.key?(:public_key_data) @valid_after_time = args[:valid_after_time] if args.key?(:valid_after_time) @valid_before_time = args[:valid_before_time] if args.key?(:valid_before_time) end |