Class: Google::Apis::IamV1::SignJwtRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Deprecated. Migrate to Service Account Credentials API. The service account sign JWT request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SignJwtRequest

Returns a new instance of SignJwtRequest.



2872
2873
2874
# File 'lib/google/apis/iam_v1/classes.rb', line 2872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#payloadString

Required. Deprecated. Migrate to Service Account Credentials API. The JWT payload to sign. Must be a serialized JSON object that contains a JWT Claims Set. For example: "sub": "user@example.com", "iat": 313435`If the JWT Claims Set contains an expiration time (exp) claim, it must be an integer timestamp that is not in the past and no more than 12 hours in the future. If the JWT Claims Set does not contain an expiration time (exp) claim, this claim is added automatically, with a timestamp that is 1 hour in the future. Corresponds to the JSON propertypayload`

Returns:

  • (String)


2870
2871
2872
# File 'lib/google/apis/iam_v1/classes.rb', line 2870

def payload
  @payload
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2877
2878
2879
# File 'lib/google/apis/iam_v1/classes.rb', line 2877

def update!(**args)
  @payload = args[:payload] if args.key?(:payload)
end