Class: Google::Apis::IamV1::WorkforcePool
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::WorkforcePool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents a collection of external workforces. Provides namespaces for federated users that can be referenced in IAM policies.
Instance Attribute Summary collapse
-
#access_restrictions ⇒ Google::Apis::IamV1::AccessRestrictions
Access related restrictions on the workforce pool.
-
#description ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#parent ⇒ String
Immutable.
-
#session_duration ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkforcePool
constructor
A new instance of WorkforcePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkforcePool
Returns a new instance of WorkforcePool.
3347 3348 3349 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_restrictions ⇒ Google::Apis::IamV1::AccessRestrictions
Access related restrictions on the workforce pool.
Corresponds to the JSON property accessRestrictions
3294 3295 3296 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3294 def access_restrictions @access_restrictions end |
#description ⇒ String
Optional. A description of the pool. Cannot exceed 256 characters.
Corresponds to the JSON property description
3299 3300 3301 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3299 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Disables the workforce pool. You cannot use a disabled pool to
exchange tokens, or use existing tokens to access resources. If the pool is re-
enabled, existing tokens grant access again.
Corresponds to the JSON property disabled
3306 3307 3308 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3306 def disabled @disabled end |
#display_name ⇒ String
Optional. A display name for the pool. Cannot exceed 32 characters.
Corresponds to the JSON property displayName
3312 3313 3314 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3312 def display_name @display_name end |
#expire_time ⇒ String
Output only. Time after which the workforce pool will be permanently purged
and cannot be recovered.
Corresponds to the JSON property expireTime
3318 3319 3320 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3318 def expire_time @expire_time end |
#name ⇒ String
Identifier. The resource name of the pool. Format: locations/location/
workforcePools/workforce_pool_id`
Corresponds to the JSON propertyname`
3324 3325 3326 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3324 def name @name end |
#parent ⇒ String
Immutable. The resource name of the parent. Format: organizations/org-id`.
Corresponds to the JSON propertyparent`
3329 3330 3331 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3329 def parent @parent end |
#session_duration ⇒ String
Optional. Duration that the Google Cloud access tokens, console sign-in
sessions, and gcloud sign-in sessions from this pool are valid. Must be
greater than 15 minutes (900s) and less than 12 hours (43200s). If
session_duration is not configured, minted credentials have a default
duration of one hour (3600s). For SAML providers, the lifetime of the token is
the minimum of the session_duration and the SessionNotOnOrAfter claim in
the SAML assertion.
Corresponds to the JSON property sessionDuration
3340 3341 3342 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3340 def session_duration @session_duration end |
#state ⇒ String
Output only. The state of the pool.
Corresponds to the JSON property state
3345 3346 3347 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3345 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3352 3353 3354 3355 3356 3357 3358 3359 3360 3361 3362 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3352 def update!(**args) @access_restrictions = args[:access_restrictions] if args.key?(:access_restrictions) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @session_duration = args[:session_duration] if args.key?(:session_duration) @state = args[:state] if args.key?(:state) end |