Class: Google::Apis::IamV1::WorkforcePoolProvider
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::WorkforcePoolProvider
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
A configuration for an external identity provider.
Instance Attribute Summary collapse
-
#attribute_condition ⇒ String
Optional.
-
#attribute_mapping ⇒ Hash<String,String>
Required.
-
#description ⇒ String
Optional.
-
#detailed_audit_logging ⇒ Boolean
(also: #detailed_audit_logging?)
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#extended_attributes_oauth2_client ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
Represents the OAuth 2.0 client credential configuration for retrieving additional user attributes that are not present in the initial authentication credentials from the identity provider, for example, groups.
-
#extra_attributes_oauth2_client ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
Represents the OAuth 2.0 client credential configuration for retrieving additional user attributes that are not present in the initial authentication credentials from the identity provider, for example, groups.
-
#name ⇒ String
Identifier.
-
#oidc ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidc
Represents an OpenID Connect 1.0 identity provider.
-
#saml ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderSaml
Represents a SAML identity provider.
-
#scim_usage ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkforcePoolProvider
constructor
A new instance of WorkforcePoolProvider.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkforcePoolProvider
Returns a new instance of WorkforcePoolProvider.
3514 3515 3516 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_condition ⇒ String
Optional. A Common Expression Language expression, in plain text, to restrict what otherwise valid
authentication credentials issued by the provider should not be accepted. The
expression must output a boolean representing whether to allow the federation.
The following keywords may be referenced in the expressions: * assertion:
JSON representing the authentication credential issued by the provider. *
google: The Google attributes mapped from the assertion in the
attribute_mappings. google.profile_photo, google.display_name and google.
posix_username are not supported. * attribute: The custom attributes mapped
from the assertion in the attribute_mappings. The maximum length of the
attribute condition expression is 4096 characters. If unspecified, all valid
authentication credentials will be accepted. The following example shows how
to only allow credentials with a mapped google.groups value of admins:
"'admins' in google.groups"
Corresponds to the JSON property attributeCondition
3387 3388 3389 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3387 def attribute_condition @attribute_condition end |
#attribute_mapping ⇒ Hash<String,String>
Required. Maps attributes from the authentication credentials issued by an
external identity provider to Google Cloud attributes, such as subject and
segment. Each key must be a string specifying the Google Cloud IAM attribute
to map to. The following keys are supported: * google.subject: The principal
IAM is authenticating. You can reference this value in IAM bindings. This is
also the subject that appears in Cloud Logging logs. This is a required field
and the mapped subject cannot exceed 127 bytes. * google.groups: Groups the
authenticating user belongs to. You can grant groups access to resources using
an IAM principalSet binding; access applies to all members of the group. *
google.display_name: The name of the authenticated user. This is an optional
field and the mapped display name cannot exceed 100 bytes. If not set, google.
subject will be displayed instead. This attribute cannot be referenced in IAM
bindings. * google.profile_photo: The URL that specifies the authenticated
user's thumbnail photo. This is an optional field. When set, the image will be
visible as the user's profile picture. If not set, a generic user icon will be
displayed instead. This attribute cannot be referenced in IAM bindings. *
google.posix_username: The Linux username used by OS Login. This is an
optional field and the mapped POSIX username cannot exceed 32 characters. The
key must match the regex ^a-zA-Z0-9._0,31$. This attribute cannot be
referenced in IAM bindings. You can also provide custom attributes by
specifying attribute.custom_attribute, where `custom_attribute` is the
name of the custom attribute to be mapped. You can define a maximum of 50
custom attributes. The maximum length of a mapped attribute key is 100
characters, and the key may only contain the characters `[a-z0-9_]`. You can
reference these attributes in IAM policies to define fine-grained access for a
workforce pool to Google Cloud resources. For example: * `google.subject`: `
principal://iam.googleapis.com/locations/global/workforcePools/`pool`/subject/`
value * google.groups: principalSet://iam.googleapis.com/locations/global/
workforcePools/pool/group/value* `attribute.`custom_attribute:
principalSet://iam.googleapis.com/locations/global/workforcePools/pool/
attribute.custom_attribute/valueEach value must be a [Common Expression
Language] (https://opensource.google/projects/cel) function that maps an
identity provider credential to the normalized attribute specified by the
corresponding map key. You can use the `assertion` keyword in the expression
to access a JSON representation of the authentication credential issued by the
provider. The maximum length of an attribute mapping expression is 2048
characters. When evaluated, the total size of all mapped attributes must not
exceed 16 KB. For OIDC providers, you must supply a custom mapping that
includes the `google.subject` attribute. For example, the following maps the `
sub` claim of the incoming credential to the `subject` attribute on a Google
token:"google.subject": "assertion.sub"`
Corresponds to the JSON propertyattributeMapping`
3432 3433 3434 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3432 def attribute_mapping @attribute_mapping end |
#description ⇒ String
Optional. A description of the provider. Cannot exceed 256 characters.
Corresponds to the JSON property description
3437 3438 3439 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3437 def description @description end |
#detailed_audit_logging ⇒ Boolean Also known as: detailed_audit_logging?
Optional. If true, populates additional debug information in Cloud Audit Logs
for this provider. Logged attribute mappings and values can be found in sts.
googleapis.com data access logs. Default value is false.
Corresponds to the JSON property detailedAuditLogging
3444 3445 3446 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3444 def detailed_audit_logging @detailed_audit_logging end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Disables the workforce pool provider. You cannot use a disabled
provider to exchange tokens. However, existing tokens still grant access.
Corresponds to the JSON property disabled
3451 3452 3453 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3451 def disabled @disabled end |
#display_name ⇒ String
Optional. A display name for the provider. Cannot exceed 32 characters.
Corresponds to the JSON property displayName
3457 3458 3459 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3457 def display_name @display_name end |
#expire_time ⇒ String
Output only. Time after which the workforce identity pool provider will be
permanently purged and cannot be recovered.
Corresponds to the JSON property expireTime
3463 3464 3465 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3463 def expire_time @expire_time end |
#extended_attributes_oauth2_client ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
Represents the OAuth 2.0 client credential configuration for retrieving
additional user attributes that are not present in the initial authentication
credentials from the identity provider, for example, groups. See https://
datatracker.ietf.org/doc/html/rfc6749#section-4.4 for more details on client
credentials grant flow.
Corresponds to the JSON property extendedAttributesOauth2Client
3472 3473 3474 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3472 def extended_attributes_oauth2_client @extended_attributes_oauth2_client end |
#extra_attributes_oauth2_client ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client
Represents the OAuth 2.0 client credential configuration for retrieving
additional user attributes that are not present in the initial authentication
credentials from the identity provider, for example, groups. See https://
datatracker.ietf.org/doc/html/rfc6749#section-4.4 for more details on client
credentials grant flow.
Corresponds to the JSON property extraAttributesOauth2Client
3481 3482 3483 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3481 def extra_attributes_oauth2_client @extra_attributes_oauth2_client end |
#name ⇒ String
Identifier. The resource name of the provider. Format: locations/location/
workforcePools/workforce_pool_id/providers/provider_id`
Corresponds to the JSON propertyname`
3487 3488 3489 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3487 def name @name end |
#oidc ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderOidc
Represents an OpenID Connect 1.0 identity provider.
Corresponds to the JSON property oidc
3492 3493 3494 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3492 def oidc @oidc end |
#saml ⇒ Google::Apis::IamV1::GoogleIamAdminV1WorkforcePoolProviderSaml
Represents a SAML identity provider.
Corresponds to the JSON property saml
3497 3498 3499 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3497 def saml @saml end |
#scim_usage ⇒ String
Optional. Gemini Enterprise only. Specifies whether the workforce identity
pool provider uses SCIM-managed groups instead of the google.groups
attribute mapping for authorization checks. The scim_usage and
extended_attributes_oauth2_client fields are mutually exclusive. A request
that enables both fields on the same workforce identity pool provider will
produce an error.
Corresponds to the JSON property scimUsage
3507 3508 3509 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3507 def scim_usage @scim_usage end |
#state ⇒ String
Output only. The state of the provider.
Corresponds to the JSON property state
3512 3513 3514 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3512 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3519 3520 3521 3522 3523 3524 3525 3526 3527 3528 3529 3530 3531 3532 3533 3534 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3519 def update!(**args) @attribute_condition = args[:attribute_condition] if args.key?(:attribute_condition) @attribute_mapping = args[:attribute_mapping] if args.key?(:attribute_mapping) @description = args[:description] if args.key?(:description) @detailed_audit_logging = args[:detailed_audit_logging] if args.key?(:detailed_audit_logging) @disabled = args[:disabled] if args.key?(:disabled) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @extended_attributes_oauth2_client = args[:extended_attributes_oauth2_client] if args.key?(:extended_attributes_oauth2_client) @extra_attributes_oauth2_client = args[:extra_attributes_oauth2_client] if args.key?(:extra_attributes_oauth2_client) @name = args[:name] if args.key?(:name) @oidc = args[:oidc] if args.key?(:oidc) @saml = args[:saml] if args.key?(:saml) @scim_usage = args[:scim_usage] if args.key?(:scim_usage) @state = args[:state] if args.key?(:state) end |