Class: Google::Apis::IamV1::WorkforcePoolProviderKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a public key configuration for a Workforce Pool Provider. The key can be configured in your identity provider to encrypt SAML assertions. Google holds the corresponding private key, which it uses to decrypt encrypted tokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkforcePoolProviderKey

Returns a new instance of WorkforcePoolProviderKey.



3571
3572
3573
# File 'lib/google/apis/iam_v1/classes.rb', line 3571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Output only. The time after which the key will be permanently deleted and cannot be recovered. Note that the key may get purged before this time if the total limit of keys per provider is exceeded. Corresponds to the JSON property expireTime

Returns:

  • (String)


3548
3549
3550
# File 'lib/google/apis/iam_v1/classes.rb', line 3548

def expire_time
  @expire_time
end

#key_dataGoogle::Apis::IamV1::KeyData

Represents a public key data along with its format. Corresponds to the JSON property keyData



3553
3554
3555
# File 'lib/google/apis/iam_v1/classes.rb', line 3553

def key_data
  @key_data
end

#nameString

Identifier. The resource name of the key. Format: locations/location/ workforcePools/workforce_pool_id/providers/provider_id/keys/key_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


3559
3560
3561
# File 'lib/google/apis/iam_v1/classes.rb', line 3559

def name
  @name
end

#stateString

Output only. The state of the key. Corresponds to the JSON property state

Returns:

  • (String)


3564
3565
3566
# File 'lib/google/apis/iam_v1/classes.rb', line 3564

def state
  @state
end

#useString

Required. The purpose of the key. Corresponds to the JSON property use

Returns:

  • (String)


3569
3570
3571
# File 'lib/google/apis/iam_v1/classes.rb', line 3569

def use
  @use
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3576
3577
3578
3579
3580
3581
3582
# File 'lib/google/apis/iam_v1/classes.rb', line 3576

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @key_data = args[:key_data] if args.key?(:key_data)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @use = args[:use] if args.key?(:use)
end