Class: Google::Apis::IamV1::WorkloadIdentityPool
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::WorkloadIdentityPool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents a collection of workload identities. You can define IAM policies to grant these identities access to Google Cloud resources.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#inline_certificate_issuance_config ⇒ Google::Apis::IamV1::InlineCertificateIssuanceConfig
Represents configuration for generating mutual TLS (mTLS) certificates for the identities within this pool.
-
#inline_trust_config ⇒ Google::Apis::IamV1::InlineTrustConfig
Defines configuration for extending trust to additional trust domains.
-
#mode ⇒ String
Immutable.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityPool
constructor
A new instance of WorkloadIdentityPool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityPool
Returns a new instance of WorkloadIdentityPool.
3758 3759 3760 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3758 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. A description of the pool. Cannot exceed 256 characters.
Corresponds to the JSON property description
3707 3708 3709 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3707 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Whether the pool is disabled. You cannot use a disabled pool to
exchange tokens, or use existing tokens to access resources. If the pool is re-
enabled, existing tokens grant access again.
Corresponds to the JSON property disabled
3714 3715 3716 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3714 def disabled @disabled end |
#display_name ⇒ String
Optional. A display name for the pool. Cannot exceed 32 characters.
Corresponds to the JSON property displayName
3720 3721 3722 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3720 def display_name @display_name end |
#expire_time ⇒ String
Output only. Time after which the workload identity pool will be permanently
purged and cannot be recovered.
Corresponds to the JSON property expireTime
3726 3727 3728 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3726 def expire_time @expire_time end |
#inline_certificate_issuance_config ⇒ Google::Apis::IamV1::InlineCertificateIssuanceConfig
Represents configuration for generating mutual TLS (mTLS) certificates for the
identities within this pool.
Corresponds to the JSON property inlineCertificateIssuanceConfig
3732 3733 3734 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3732 def inline_certificate_issuance_config @inline_certificate_issuance_config end |
#inline_trust_config ⇒ Google::Apis::IamV1::InlineTrustConfig
Defines configuration for extending trust to additional trust domains. By
establishing trust with another domain, the current domain will recognize and
accept certificates issued by entities within the trusted domains. Note that a
trust domain automatically trusts itself, eliminating the need for explicit
configuration.
Corresponds to the JSON property inlineTrustConfig
3741 3742 3743 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3741 def inline_trust_config @inline_trust_config end |
#mode ⇒ String
Immutable. The mode the pool is operating in.
Corresponds to the JSON property mode
3746 3747 3748 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3746 def mode @mode end |
#name ⇒ String
Identifier. The resource name of the pool.
Corresponds to the JSON property name
3751 3752 3753 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3751 def name @name end |
#state ⇒ String
Output only. The state of the pool.
Corresponds to the JSON property state
3756 3757 3758 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3756 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3763 def update!(**args) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @inline_certificate_issuance_config = args[:inline_certificate_issuance_config] if args.key?(:inline_certificate_issuance_config) @inline_trust_config = args[:inline_trust_config] if args.key?(:inline_trust_config) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |