Class: Google::Apis::IamV1::WorkloadIdentityPool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a collection of workload identities. You can define IAM policies to grant these identities access to Google Cloud resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityPool

Returns a new instance of WorkloadIdentityPool.



3772
3773
3774
# File 'lib/google/apis/iam_v1/classes.rb', line 3772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. A description of the pool. Cannot exceed 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


3721
3722
3723
# File 'lib/google/apis/iam_v1/classes.rb', line 3721

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Whether the pool is disabled. You cannot use a disabled pool to exchange tokens, or use existing tokens to access resources. If the pool is re- enabled, existing tokens grant access again. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3728
3729
3730
# File 'lib/google/apis/iam_v1/classes.rb', line 3728

def disabled
  @disabled
end

#display_nameString

Optional. A display name for the pool. Cannot exceed 32 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3734
3735
3736
# File 'lib/google/apis/iam_v1/classes.rb', line 3734

def display_name
  @display_name
end

#expire_timeString

Output only. Time after which the workload identity pool will be permanently purged and cannot be recovered. Corresponds to the JSON property expireTime

Returns:

  • (String)


3740
3741
3742
# File 'lib/google/apis/iam_v1/classes.rb', line 3740

def expire_time
  @expire_time
end

#inline_certificate_issuance_configGoogle::Apis::IamV1::InlineCertificateIssuanceConfig

Represents configuration for generating mutual TLS (mTLS) certificates for the identities within this pool. Corresponds to the JSON property inlineCertificateIssuanceConfig



3746
3747
3748
# File 'lib/google/apis/iam_v1/classes.rb', line 3746

def inline_certificate_issuance_config
  @inline_certificate_issuance_config
end

#inline_trust_configGoogle::Apis::IamV1::InlineTrustConfig

Defines configuration for extending trust to additional trust domains. By establishing trust with another domain, the current domain will recognize and accept certificates issued by entities within the trusted domains. Note that a trust domain automatically trusts itself, eliminating the need for explicit configuration. Corresponds to the JSON property inlineTrustConfig



3755
3756
3757
# File 'lib/google/apis/iam_v1/classes.rb', line 3755

def inline_trust_config
  @inline_trust_config
end

#modeString

Immutable. The mode the pool is operating in. Corresponds to the JSON property mode

Returns:

  • (String)


3760
3761
3762
# File 'lib/google/apis/iam_v1/classes.rb', line 3760

def mode
  @mode
end

#nameString

Identifier. The resource name of the pool. Corresponds to the JSON property name

Returns:

  • (String)


3765
3766
3767
# File 'lib/google/apis/iam_v1/classes.rb', line 3765

def name
  @name
end

#stateString

Output only. The state of the pool. Corresponds to the JSON property state

Returns:

  • (String)


3770
3771
3772
# File 'lib/google/apis/iam_v1/classes.rb', line 3770

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3777
3778
3779
3780
3781
3782
3783
3784
3785
3786
3787
# File 'lib/google/apis/iam_v1/classes.rb', line 3777

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @inline_certificate_issuance_config = args[:inline_certificate_issuance_config] if args.key?(:inline_certificate_issuance_config)
  @inline_trust_config = args[:inline_trust_config] if args.key?(:inline_trust_config)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end