Class: Google::Apis::IamV1::WorkloadIdentityPoolManagedIdentity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a managed identity for a workload identity pool namespace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityPoolManagedIdentity

Returns a new instance of WorkloadIdentityPoolManagedIdentity.



3825
3826
3827
# File 'lib/google/apis/iam_v1/classes.rb', line 3825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. A description of the managed identity. Cannot exceed 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


3799
3800
3801
# File 'lib/google/apis/iam_v1/classes.rb', line 3799

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Whether the managed identity is disabled. If disabled, credentials may no longer be issued for the identity, however existing credentials will still be accepted until they expire. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3806
3807
3808
# File 'lib/google/apis/iam_v1/classes.rb', line 3806

def disabled
  @disabled
end

#expire_timeString

Output only. Time after which the managed identity will be permanently purged and cannot be recovered. Corresponds to the JSON property expireTime

Returns:

  • (String)


3813
3814
3815
# File 'lib/google/apis/iam_v1/classes.rb', line 3813

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the managed identity. Corresponds to the JSON property name

Returns:

  • (String)


3818
3819
3820
# File 'lib/google/apis/iam_v1/classes.rb', line 3818

def name
  @name
end

#stateString

Output only. The state of the managed identity. Corresponds to the JSON property state

Returns:

  • (String)


3823
3824
3825
# File 'lib/google/apis/iam_v1/classes.rb', line 3823

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3830
3831
3832
3833
3834
3835
3836
# File 'lib/google/apis/iam_v1/classes.rb', line 3830

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end