Class: Google::Apis::IamV1::WorkloadIdentityPoolManagedIdentity
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::WorkloadIdentityPoolManagedIdentity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents a managed identity for a workload identity pool namespace.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#expire_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityPoolManagedIdentity
constructor
A new instance of WorkloadIdentityPoolManagedIdentity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityPoolManagedIdentity
Returns a new instance of WorkloadIdentityPoolManagedIdentity.
3825 3826 3827 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. A description of the managed identity. Cannot exceed 256 characters.
Corresponds to the JSON property description
3799 3800 3801 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3799 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Whether the managed identity is disabled. If disabled, credentials
may no longer be issued for the identity, however existing credentials will
still be accepted until they expire.
Corresponds to the JSON property disabled
3806 3807 3808 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3806 def disabled @disabled end |
#expire_time ⇒ String
Output only. Time after which the managed identity will be permanently purged
and cannot be recovered.
Corresponds to the JSON property expireTime
3813 3814 3815 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3813 def expire_time @expire_time end |
#name ⇒ String
Identifier. The resource name of the managed identity.
Corresponds to the JSON property name
3818 3819 3820 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3818 def name @name end |
#state ⇒ String
Output only. The state of the managed identity.
Corresponds to the JSON property state
3823 3824 3825 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3823 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3830 3831 3832 3833 3834 3835 3836 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3830 def update!(**args) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |