Class: Google::Apis::IamV1::WorkloadIdentityPoolNamespace
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::WorkloadIdentityPoolNamespace
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents a namespace for a workload identity pool. Namespaces are used to segment identities within the pool.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#expire_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#owner_service ⇒ Google::Apis::IamV1::OwnerService
The Google Cloud service that owns this namespace.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityPoolNamespace
constructor
A new instance of WorkloadIdentityPoolNamespace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityPoolNamespace
Returns a new instance of WorkloadIdentityPoolNamespace.
3878 3879 3880 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. A description of the namespace. Cannot exceed 256 characters.
Corresponds to the JSON property description
3847 3848 3849 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3847 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Whether the namespace is disabled. If disabled, credentials may no
longer be issued for identities within this namespace, however existing
credentials will still be accepted until they expire.
Corresponds to the JSON property disabled
3854 3855 3856 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3854 def disabled @disabled end |
#expire_time ⇒ String
Output only. Time after which the namespace will be permanently purged and
cannot be recovered.
Corresponds to the JSON property expireTime
3861 3862 3863 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3861 def expire_time @expire_time end |
#name ⇒ String
Identifier. The resource name of the namespace.
Corresponds to the JSON property name
3866 3867 3868 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3866 def name @name end |
#owner_service ⇒ Google::Apis::IamV1::OwnerService
The Google Cloud service that owns this namespace.
Corresponds to the JSON property ownerService
3871 3872 3873 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3871 def owner_service @owner_service end |
#state ⇒ String
Output only. The state of the namespace.
Corresponds to the JSON property state
3876 3877 3878 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3876 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3883 3884 3885 3886 3887 3888 3889 3890 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3883 def update!(**args) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @owner_service = args[:owner_service] if args.key?(:owner_service) @state = args[:state] if args.key?(:state) end |