Class: Google::Apis::IamV1::WorkloadIdentityPoolNamespace
- Inherits:
-
Object
- Object
- Google::Apis::IamV1::WorkloadIdentityPoolNamespace
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb
Overview
Represents a namespace for a workload identity pool. Namespaces are used to segment identities within the pool.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#disabled ⇒ Boolean
(also: #disabled?)
Optional.
-
#expire_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#owner_service ⇒ Google::Apis::IamV1::OwnerService
The Google Cloud service that owns this namespace.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityPoolNamespace
constructor
A new instance of WorkloadIdentityPoolNamespace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityPoolNamespace
Returns a new instance of WorkloadIdentityPoolNamespace.
3867 3868 3869 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. A description of the namespace. Cannot exceed 256 characters.
Corresponds to the JSON property description
3836 3837 3838 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3836 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Optional. Whether the namespace is disabled. If disabled, credentials may no
longer be issued for identities within this namespace, however existing
credentials will still be accepted until they expire.
Corresponds to the JSON property disabled
3843 3844 3845 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3843 def disabled @disabled end |
#expire_time ⇒ String
Output only. Time after which the namespace will be permanently purged and
cannot be recovered.
Corresponds to the JSON property expireTime
3850 3851 3852 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3850 def expire_time @expire_time end |
#name ⇒ String
Output only. The resource name of the namespace.
Corresponds to the JSON property name
3855 3856 3857 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3855 def name @name end |
#owner_service ⇒ Google::Apis::IamV1::OwnerService
The Google Cloud service that owns this namespace.
Corresponds to the JSON property ownerService
3860 3861 3862 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3860 def owner_service @owner_service end |
#state ⇒ String
Output only. The state of the namespace.
Corresponds to the JSON property state
3865 3866 3867 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3865 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3872 3873 3874 3875 3876 3877 3878 3879 |
# File 'lib/google/apis/iam_v1/classes.rb', line 3872 def update!(**args) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @owner_service = args[:owner_service] if args.key?(:owner_service) @state = args[:state] if args.key?(:state) end |