Class: Google::Apis::IamV1::WorkloadIdentityPoolProvider

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

A configuration for an external identity provider.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityPoolProvider

Returns a new instance of WorkloadIdentityPoolProvider.



4023
4024
4025
# File 'lib/google/apis/iam_v1/classes.rb', line 4023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_conditionString

Optional. A Common Expression Language expression, in plain text, to restrict what otherwise valid authentication credentials issued by the provider should not be accepted. The expression must output a boolean representing whether to allow the federation. The following keywords may be referenced in the expressions: * assertion: JSON representing the authentication credential issued by the provider. * google: The Google attributes mapped from the assertion in the attribute_mappings. * attribute: The custom attributes mapped from the assertion in the attribute_mappings. The maximum length of the attribute condition expression is 4096 characters. If unspecified, all valid authentication credential are accepted. The following example shows how to only allow credentials with a mapped google.groups value of admins: "' admins' in google.groups" Corresponds to the JSON property attributeCondition

Returns:

  • (String)


3925
3926
3927
# File 'lib/google/apis/iam_v1/classes.rb', line 3925

def attribute_condition
  @attribute_condition
end

#attribute_mappingHash<String,String>

Optional. Maps attributes from authentication credentials issued by an external identity provider to Google Cloud attributes, such as subject and segment. Each key must be a string specifying the Google Cloud IAM attribute to map to. The following keys are supported: * google.subject: The principal IAM is authenticating. You can reference this value in IAM bindings. This is also the subject that appears in Cloud Logging logs. Cannot exceed 127 bytes. * google.groups: Groups the external identity belongs to. You can grant groups access to resources using an IAM principalSet binding; access applies to all members of the group. You can also provide custom attributes by specifying attribute.custom_attribute, wherecustom_attributeis the name of the custom attribute to be mapped. You can define a maximum of 50 custom attributes. The maximum length of a mapped attribute key is 100 characters, and the key may only contain the characters [a-z0-9_]. You can reference these attributes in IAM policies to define fine-grained access for a workload to Google Cloud resources. For example: * `google.subject`: ` principal://iam.googleapis.com/projects/`project`/locations/`location`/ workloadIdentityPools/`pool`/subject/`value * google.groups: principalSet: //iam.googleapis.com/projects/project/locations/location/ workloadIdentityPools/pool/group/value* `attribute.`custom_attribute: principalSet://iam.googleapis.com/projects/project/locations/location/ workloadIdentityPools/pool/attribute.custom_attribute/valueEach value must be a [Common Expression Language] (https://opensource.google/projects/cel) function that maps an identity provider credential to the normalized attribute specified by the corresponding map key. You can use the `assertion` keyword in the expression to access a JSON representation of the authentication credential issued by the provider. The maximum length of an attribute mapping expression is 2048 characters. When evaluated, the total size of all mapped attributes must not exceed 8KB. For AWS providers, if no attribute mapping is defined, the following default mapping applies: " google.subject":"assertion.arn", "attribute.aws_role": "assertion.arn.contains( 'assumed-role')" " ? assertion.arn.extract('account_arnassumed-role/')" " + ' assumed-role/'" " + assertion.arn.extract('assumed-role/role_name/')" " : assertion.arn", If any custom attribute mappings are defined, they must include a mapping to the `google.subject` attribute. For OIDC providers, you must supply a custom mapping, which must include the `google.subject` attribute. For example, the following maps the `sub` claim of the incoming credential to the `subject` attribute on a Google token:"google.subject": "assertion.sub"` Corresponds to the JSON propertyattributeMapping`

Returns:

  • (Hash<String,String>)


3967
3968
3969
# File 'lib/google/apis/iam_v1/classes.rb', line 3967

def attribute_mapping
  @attribute_mapping
end

#awsGoogle::Apis::IamV1::Aws

Represents an Amazon Web Services identity provider. Corresponds to the JSON property aws



3972
3973
3974
# File 'lib/google/apis/iam_v1/classes.rb', line 3972

def aws
  @aws
end

#descriptionString

Optional. A description for the provider. Cannot exceed 256 characters. Corresponds to the JSON property description

Returns:

  • (String)


3977
3978
3979
# File 'lib/google/apis/iam_v1/classes.rb', line 3977

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Whether the provider is disabled. You cannot use a disabled provider to exchange tokens. However, existing tokens still grant access. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3983
3984
3985
# File 'lib/google/apis/iam_v1/classes.rb', line 3983

def disabled
  @disabled
end

#display_nameString

Optional. A display name for the provider. Cannot exceed 32 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3989
3990
3991
# File 'lib/google/apis/iam_v1/classes.rb', line 3989

def display_name
  @display_name
end

#expire_timeString

Output only. Time after which the workload identity pool provider will be permanently purged and cannot be recovered. Corresponds to the JSON property expireTime

Returns:

  • (String)


3995
3996
3997
# File 'lib/google/apis/iam_v1/classes.rb', line 3995

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the provider. Corresponds to the JSON property name

Returns:

  • (String)


4000
4001
4002
# File 'lib/google/apis/iam_v1/classes.rb', line 4000

def name
  @name
end

#oidcGoogle::Apis::IamV1::Oidc

Represents an OpenId Connect 1.0 identity provider. Corresponds to the JSON property oidc



4005
4006
4007
# File 'lib/google/apis/iam_v1/classes.rb', line 4005

def oidc
  @oidc
end

#samlGoogle::Apis::IamV1::Saml

Represents an SAML 2.0 identity provider. Corresponds to the JSON property saml



4010
4011
4012
# File 'lib/google/apis/iam_v1/classes.rb', line 4010

def saml
  @saml
end

#stateString

Output only. The state of the provider. Corresponds to the JSON property state

Returns:

  • (String)


4015
4016
4017
# File 'lib/google/apis/iam_v1/classes.rb', line 4015

def state
  @state
end

#x509Google::Apis::IamV1::X509

An X.509-type identity provider represents a CA. It is trusted to assert a client identity if the client has a certificate that chains up to this CA. Corresponds to the JSON property x509



4021
4022
4023
# File 'lib/google/apis/iam_v1/classes.rb', line 4021

def x509
  @x509
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
# File 'lib/google/apis/iam_v1/classes.rb', line 4028

def update!(**args)
  @attribute_condition = args[:attribute_condition] if args.key?(:attribute_condition)
  @attribute_mapping = args[:attribute_mapping] if args.key?(:attribute_mapping)
  @aws = args[:aws] if args.key?(:aws)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @oidc = args[:oidc] if args.key?(:oidc)
  @saml = args[:saml] if args.key?(:saml)
  @state = args[:state] if args.key?(:state)
  @x509 = args[:x509] if args.key?(:x509)
end