Class: Google::Apis::IamV1::WorkloadIdentityPoolProviderKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a public key configuration for your workload identity pool provider. The key can be configured in your identity provider to encrypt the SAML assertions. Google holds the corresponding private key which it uses to decrypt encrypted tokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityPoolProviderKey

Returns a new instance of WorkloadIdentityPoolProviderKey.



4078
4079
4080
# File 'lib/google/apis/iam_v1/classes.rb', line 4078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Output only. Time after which the key will be permanently purged and cannot be recovered. Note that the key may get purged before this timestamp if the total limit of keys per provider is crossed. Corresponds to the JSON property expireTime

Returns:

  • (String)


4056
4057
4058
# File 'lib/google/apis/iam_v1/classes.rb', line 4056

def expire_time
  @expire_time
end

#key_dataGoogle::Apis::IamV1::KeyData

Represents a public key data along with its format. Corresponds to the JSON property keyData



4061
4062
4063
# File 'lib/google/apis/iam_v1/classes.rb', line 4061

def key_data
  @key_data
end

#nameString

Identifier. The resource name of the key. Corresponds to the JSON property name

Returns:

  • (String)


4066
4067
4068
# File 'lib/google/apis/iam_v1/classes.rb', line 4066

def name
  @name
end

#stateString

Output only. The state of the key. Corresponds to the JSON property state

Returns:

  • (String)


4071
4072
4073
# File 'lib/google/apis/iam_v1/classes.rb', line 4071

def state
  @state
end

#useString

Required. The purpose of the key. Corresponds to the JSON property use

Returns:

  • (String)


4076
4077
4078
# File 'lib/google/apis/iam_v1/classes.rb', line 4076

def use
  @use
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4083
4084
4085
4086
4087
4088
4089
# File 'lib/google/apis/iam_v1/classes.rb', line 4083

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @key_data = args[:key_data] if args.key?(:key_data)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @use = args[:use] if args.key?(:use)
end