Class: Google::Apis::IamV1::WorkloadIdentityPoolProviderKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iam_v1/classes.rb,
lib/google/apis/iam_v1/representations.rb,
lib/google/apis/iam_v1/representations.rb

Overview

Represents a public key configuration for your workload identity pool provider. The key can be configured in your identity provider to encrypt the SAML assertions. Google holds the corresponding private key which it uses to decrypt encrypted tokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityPoolProviderKey

Returns a new instance of WorkloadIdentityPoolProviderKey.



4076
4077
4078
# File 'lib/google/apis/iam_v1/classes.rb', line 4076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expire_timeString

Output only. Time after which the key will be permanently purged and cannot be recovered. Note that the key may get purged before this timestamp if the total limit of keys per provider is crossed. Corresponds to the JSON property expireTime

Returns:

  • (String)


4054
4055
4056
# File 'lib/google/apis/iam_v1/classes.rb', line 4054

def expire_time
  @expire_time
end

#key_dataGoogle::Apis::IamV1::KeyData

Represents a public key data along with its format. Corresponds to the JSON property keyData



4059
4060
4061
# File 'lib/google/apis/iam_v1/classes.rb', line 4059

def key_data
  @key_data
end

#nameString

Identifier. The resource name of the key. Corresponds to the JSON property name

Returns:

  • (String)


4064
4065
4066
# File 'lib/google/apis/iam_v1/classes.rb', line 4064

def name
  @name
end

#stateString

Output only. The state of the key. Corresponds to the JSON property state

Returns:

  • (String)


4069
4070
4071
# File 'lib/google/apis/iam_v1/classes.rb', line 4069

def state
  @state
end

#useString

Required. The purpose of the key. Corresponds to the JSON property use

Returns:

  • (String)


4074
4075
4076
# File 'lib/google/apis/iam_v1/classes.rb', line 4074

def use
  @use
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4081
4082
4083
4084
4085
4086
4087
# File 'lib/google/apis/iam_v1/classes.rb', line 4081

def update!(**args)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @key_data = args[:key_data] if args.key?(:key_data)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @use = args[:use] if args.key?(:use)
end